'use strict';

var _utils = require('./utils.js');

var _utils2 = _interopRequireDefault(_utils);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (store, key) {
  var noKey = key === undefined;

  return {
    getInitialState: function getInitialState() {
      if (!_utils2.default.isFunction(store.getInitialState)) {
        console.warn('component ' + this.constructor.displayName + ' is trying to connect to a store that lacks "getInitialState()" method');
        return {};
      } else {
        return noKey ? store.state : _utils2.default.object([key], [store.state[key]]);
      }
    },
    componentDidMount: function componentDidMount() {

      var componentInstance = this;

      var setStateFunc = function setStateFunc(state) {
        var newState = noKey ? state : _utils2.default.object([key], [state]);

        if (typeof componentInstance.isMounted === "undefined" || componentInstance.isMounted() === true) {
          componentInstance.setState(newState);
        }
      };

      var listener = noKey ? store : store[key];

      this.unsubscribe = listener.listen(setStateFunc);
    },
    componentWillUnmount: function componentWillUnmount() {
      this.unsubscribe();
    }
  };
};